# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.swap_api import SwapApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestSwapApi(unittest.TestCase):
    """SwapApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.swap_api.SwapApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_swap_coins(self):
        """Test case for swap_coins

        Swap coins  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
