from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from zarban.wallet.openapi_client.api.auth_api import AuthApi
from zarban.wallet.openapi_client.api.balance_api import BalanceApi
from zarban.wallet.openapi_client.api.coins_api import CoinsApi
from zarban.wallet.openapi_client.api.deposit_api import DepositApi
from zarban.wallet.openapi_client.api.health_api import HealthApi
from zarban.wallet.openapi_client.api.loans_api import LoansApi
from zarban.wallet.openapi_client.api.payment_api import PaymentApi
from zarban.wallet.openapi_client.api.points_api import PointsApi
from zarban.wallet.openapi_client.api.redemptions_api import RedemptionsApi
from zarban.wallet.openapi_client.api.referrals_api import ReferralsApi
from zarban.wallet.openapi_client.api.swap_api import SwapApi
from zarban.wallet.openapi_client.api.tasks_api import TasksApi
from zarban.wallet.openapi_client.api.transactions_api import TransactionsApi
from zarban.wallet.openapi_client.api.user_api import UserApi
from zarban.wallet.openapi_client.api.withdraw_api import WithdrawApi
