# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.lending_pool_api import LendingPoolApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestLendingPoolApi(unittest.TestCase):
    """LendingPoolApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.lending_pool_api.LendingPoolApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_lending_pool_borrow(self):
        """Test case for create_lending_pool_borrow

        Borrow from lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_deposit(self):
        """Test case for create_lending_pool_deposit

        Deposit to lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_repay(self):
        """Test case for create_lending_pool_repay

        Repay to lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_withdraw(self):
        """Test case for create_lending_pool_withdraw

        Withdraw from lending pool  # noqa: E501
        """
        pass

    def test_fetch_reserve_data_by_asset(self):
        """Test case for fetch_reserve_data_by_asset

        Fetch Reserve Data By Asset  # noqa: E501
        """
        pass

    def test_get_user_borrows(self):
        """Test case for get_user_borrows

        Get user borrows of lendingpool  # noqa: E501
        """
        pass

    def test_get_user_deposits(self):
        """Test case for get_user_deposits

        Get user deposits of Lendingpool  # noqa: E501
        """
        pass

    def test_set_lending_pool_asset_collateral(self):
        """Test case for set_lending_pool_asset_collateral

        Enable/Disable asset as collateral  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
