# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.loans_response_list import LoansResponseList  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestLoansResponseList(unittest.TestCase):
    """LoansResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LoansResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.loans_response_list.LoansResponseList()  # noqa: E501
        if include_optional :
            return LoansResponseList(
                data = [
                    zarban.wallet.openapi_client.models.loans_response.LoansResponse(
                        id = '0', 
                        user_id = 56, 
                        liquidation_price = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateral = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        principal = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        scaled_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        plan = zarban.wallet.openapi_client.models.loan_plan.LoanPlan(
                            name = 'ETH-A', 
                            min_collateralization_ratio = '1.5', 
                            acceptable_coins = [
                                zarban.wallet.openapi_client.models.coin.Coin(
                                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                        is_tradeable = True, 
                                        withdraw_fees = {"tron":"10"}, 
                                        min_withdrawal = {"tron":"10"}, 
                                        needs_memo = True, ), 
                                    symbol = 'USD', 
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', 
                                    depositable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    withdrawable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                        title = '0', 
                                        text = '0', 
                                        bullets = [
                                            '0'
                                            ], ), )
                                ], 
                            fee = '0.05', 
                            max_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            min_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            loan_to_value_options = [
                                zarban.wallet.openapi_client.models.detailed_loan_to_value_options.DetailedLoanToValueOptions(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    value = '0.5', )
                                ], ), 
                        state = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        updated_collateral_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        updated_debt_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        terms_and_conditions = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ]
            )
        else :
            return LoansResponseList(
                data = [
                    zarban.wallet.openapi_client.models.loans_response.LoansResponse(
                        id = '0', 
                        user_id = 56, 
                        liquidation_price = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateral = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        principal = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        scaled_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        plan = zarban.wallet.openapi_client.models.loan_plan.LoanPlan(
                            name = 'ETH-A', 
                            min_collateralization_ratio = '1.5', 
                            acceptable_coins = [
                                zarban.wallet.openapi_client.models.coin.Coin(
                                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                        is_tradeable = True, 
                                        withdraw_fees = {"tron":"10"}, 
                                        min_withdrawal = {"tron":"10"}, 
                                        needs_memo = True, ), 
                                    symbol = 'USD', 
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', 
                                    depositable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    withdrawable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                        title = '0', 
                                        text = '0', 
                                        bullets = [
                                            '0'
                                            ], ), )
                                ], 
                            fee = '0.05', 
                            max_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            min_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            loan_to_value_options = [
                                zarban.wallet.openapi_client.models.detailed_loan_to_value_options.DetailedLoanToValueOptions(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    value = '0.5', )
                                ], ), 
                        state = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        updated_collateral_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        updated_debt_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        terms_and_conditions = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ],
        )

    def testLoansResponseList(self):
        """Test LoansResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
